
\TABLE{bg=blue separator="|" border=2}

Spalte 1  |  Spalte 2  | Spalte 3
xxxx      |  yyyy      |  zzzzz
uuuu      |  vvvv      |  wwwww

\END_TABLE


@|+crazy+@+colsep+|
Spalte 1  |+crazy+@+colsep+|  Spalte 2  |+crazy+@+colsep+| Spalte 3
xxxx      |+crazy+@+colsep+|  yyyy      |+crazy+@+colsep+|  zzzzz
uuuu      |+crazy+@+colsep+|  vvvv      |+crazy+@+colsep+|  wwwww

