
This is a simple text paragraph, a single liner.

This
is
a
multi
liner,
but
still
ONE
paragraph.

Text paragraphs, once started,
 may be continued at
                                                           ANY
position of
                         subsequent lines.

A final one for now.