
We include \INCLUDE{type=pp file="include1.pp"} something.

Continued frame source.

Now we include another file type - by declaration: \INCLUDE{type=anything file="include1.pp"}.
This can be done multiply, look: \INCLUDE{type=anything file="include1.pp"}.
\INCLUDE{type=filtered file="include1.pp"}

Now, let's include \INCLUDE{type=perl file="include.perl"}.

Ready this test.