
// Single line

//Immediate text start

// Multiple
// line (should be detected as TWO paragraphs)

// No trailing whitespace

// A trailing whitespace 

// Several trailing whitespaces                                     

// A final simple comment (without final carriage return ...)